Enumeration
IpuzAcrosticSyncDirection
Description [src]
Indicates which direction to sync the puzzle when called by the
IpuzAcrostic _fix() functions.
Indicates which direction to sync the puzzle when called by the
IpuzAcrostic _fix() functions.